-- MatchMakerMoveable
-- Copyright (c) 2014 Jean van Berlo

-- Permission is hereby granted, free of charge, to any person
-- obtaining a copy of this software and associated documentation
-- files (the "Software"), to deal in the Software without
-- restriction, including without limitation the rights to use,
-- copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the
-- Software is furnished to do so, subject to the following
-- conditions:

-- The above copyright notice and this permission notice shall be
-- included in all copies or substantial portions of the Software.

-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-- OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-- NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-- HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-- WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-- FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-- OTHER DEALINGS IN THE SOFTWARE.
 
require "Window"
require "MatchingGame"
 
-- MatchMakerMoveable Addon globals

local glog = nil;
local MatchMakerMoveable = {} 
local MatchMakerMoveableInst = nil
local cTimer = {}
local timerSettings = {
	countdown = 59
}
 
-- Init
function MatchMakerMoveable:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 
    return o
end

function MatchMakerMoveable:Init()
    Apollo.RegisterAddon(self, false, "", {"MatchMaker", "Gemini:Logging-1.2"})
end

-- MatchMakerMoveable OnLoad
function MatchMakerMoveable:OnLoad()
    -- disable for release as we don't want to include logger lib with the addon
	-- local GeminiLogging = Apollo.GetPackage("Gemini:Logging-1.2").tPackage
	-- glog = GeminiLogging:GetLogger()
    MatchMakerMoveable.MatchMaker = Apollo.GetAddon("MatchMaker")
	cTimer = ApolloTimer.Create(1, false, "OnTimer", self)
	cTimer:Stop()
	MatchMakerMoveable.mmOnDocumentReady = MatchMakerMoveable.MatchMaker.OnDocumentReady
	MatchMakerMoveable.MatchMaker.OnDocumentReady = MatchMakerMoveable.MatchMakerOnDocumentReadyHook
	MatchMakerMoveable.mmOnGameReady = MatchMakerMoveable.MatchMaker.OnGameReady
	MatchMakerMoveable.MatchMaker.OnGameReady = MatchMakerMoveable.OnGameReadyHook
	
	Apollo.RegisterEventHandler("MatchingGameReady", 					"OnGameReady", self)
	Apollo.RegisterEventHandler("MatchingGamePendingUpdate", 			"OnHandlePending", self)
	Apollo.RegisterEventHandler("MatchingCancelPendingGame", 			"OnCanclePending", self)
	Apollo.RegisterEventHandler("MatchEntered", 						"OnMatchEntered", self)
	-- Apollo.RegisterEventHandler("MatchingJoinQueue", 					"OnJoinQueue", self)
end

function MatchMakerMoveable.Debug(txt)
	if glog then 
		glog:info(txt)
	end
end

-- function MatchMakerMoveable:OnJoinQueue()
	
	-- self.Debug("Join queue")
	-- self.Debug(MatchMakerMoveable.MatchMaker.wndMain:FindChild("VendorName"):GetText())
-- end

function MatchMakerMoveable:OnMatchEntered()
	
	self.Debug('OnMatchEntered')
	cTimer:Stop()
end

function MatchMakerMoveable:OnCanclePending()

	self.Debug('OnCanclePending')
	cTimer:Stop()
end

function MatchMakerMoveable:OnHandlePending()

	self.Debug('OnHandlePending')
	tPendingInfo = MatchingGame.GetPendingInfo()
	MatchMakerMoveable.nAcceptedAllies = tPendingInfo.nAcceptedAllies
	self.Debug(tPendingInfo.nAcceptedAllies)
end

function MatchMakerMoveable:OnTimer()
	
	if not MatchingGame.IsGamePending() then
		cTimer:Stop()
		return
	end
	--if MatchMakerMoveable.nAcceptedAllies <= 0 and timerSettings.countdown >= 59 then
		MatchMakerMoveable.MatchMaker.wndJoinGame:FindChild("Title"):SetText(MatchMakerMoveable.TitleTxt .. "\n" .. timerSettings.countdown .. "s left")
	--else
		--MatchMakerMoveable.MatchMaker.wndJoinGame:FindChild("Title"):SetText(MatchMakerMoveable.TitleTxt .. "\n" .. "Game in Progress..")
	--end
	timerSettings.countdown = timerSettings.countdown - 1;
	if timerSettings.countdown <= 0 then
		cTimer:Stop()
		return
	end
	cTimer = ApolloTimer.Create(1, false, "OnTimer", self)
end

-- MatchMakerMoveable hook into matchmaker window
function MatchMakerMoveable.MatchMakerOnDocumentReadyHook(self)
	MatchMakerMoveable.mmOnDocumentReady(self)
	self.eSelectedTab = MatchingGame.MatchType.Battleground
	self.wndJoinGame:SetStyle("Moveable", true)
end

-- MatchMakerMoveable hook into matchmaker window
function MatchMakerMoveable.OnGameReadyHook(self)
	MatchMakerMoveable.mmOnGameReady(self)
	MatchMakerMoveable.TitleTxt = MatchMakerMoveable.MatchMaker.wndJoinGame:FindChild("Title"):GetText()
	tPendingInfo = MatchingGame.GetPendingInfo()
	MatchMakerMoveable.nAcceptedAllies = tPendingInfo.nAcceptedAllies
	timerSettings.countdown = 59
	cTimer:Start()
end

-- MatchMakerMoveable instantiate
MatchMakerMoveableInst = MatchMakerMoveable:new()
MatchMakerMoveableInst:Init()